@@ -1,7 +1,4 @@
 comment = {
-    'info-general': {
-        'website': "Input your company's website"
-    },
     'table-education': {
         'is_trade': "是否是技工类别？比如水电工"
     },
