@@ -7,8 +7,8 @@ from openpyxl.utils import get_column_letter
 from collections import OrderedDict
 from source.infosheet import SheetDict
 from source.tablesheet import TableList
-from source.style import style
-from source.format import Format
+# from source.style import style
+# from source.format import Format
 from source.excelwriter import ExcelWritter
 
             
@@ -279,15 +279,17 @@ class Excel(object):
         #保存为新文件
         if len(self.sheets)>0 or len(self.tables)>0:    
             self.new_wb.remove(self.new_wb['Sheet']) #exists only when niether info nor table has sheet 
-        f=Format(self.new_wb)
-        f.setAll()
-        if protection:
-            f.protectAll()
-        self.new_wb.save(file_name)
-        # print(colored(f'{file_name} is saved.','green'))
-
-    def makeFormatedExcel(self,output_file_name,protection=True):
-        ew = ExcelWritter(self,output_file_name)
+        # old version, removed
+        # f=Format(self.new_wb)
+        # f.setAll()
+        # if protection:
+        #     f.protectAll()
+        self.new_wb.save(file_name) #先保存
+        self.formatExcel(file_name,protection) # format这个文件
+        
+    def formatExcel(self,output_file_name,protection=True):
+        input_excel_obj=Excel(output_file_name) #get excel obj for format
+        ew = ExcelWritter(input_excel_obj,output_file_name)
         if protection:
             password=input("please input password:")
             ew.create(protection, password)
